
.. note: DO NOT EDIT THIS FILE!
    This file is automatically generated by hpy.tools.autogen.doc.autogen_function_index
    See also hpy.tools.autogen and hpy/tools/public_api.h

    Run this to regenerate:
        make autogen

HPy Core API Function Index
###########################

* :c:func:`HPyBool_FromBool`
* :c:func:`HPyBytes_AS_STRING`
* :c:func:`HPyBytes_AsString`
* :c:func:`HPyBytes_Check`
* :c:func:`HPyBytes_FromString`
* :c:func:`HPyBytes_FromStringAndSize`
* :c:func:`HPyBytes_GET_SIZE`
* :c:func:`HPyBytes_Size`
* :c:func:`HPyCallable_Check`
* :c:func:`HPyCapsule_Get`
* :c:func:`HPyCapsule_IsValid`
* :c:func:`HPyCapsule_New`
* :c:func:`HPyCapsule_Set`
* :c:func:`HPyContextVar_Get`
* :c:func:`HPyContextVar_New`
* :c:func:`HPyContextVar_Set`
* :c:func:`HPyDict_Check`
* :c:func:`HPyDict_Copy`
* :c:func:`HPyDict_Keys`
* :c:func:`HPyDict_New`
* :c:func:`HPyErr_Clear`
* :c:func:`HPyErr_ExceptionMatches`
* :c:func:`HPyErr_NewException`
* :c:func:`HPyErr_NewExceptionWithDoc`
* :c:func:`HPyErr_NoMemory`
* :c:func:`HPyErr_Occurred`
* :c:func:`HPyErr_SetFromErrnoWithFilename`
* :c:func:`HPyErr_SetFromErrnoWithFilenameObjects`
* :c:func:`HPyErr_SetObject`
* :c:func:`HPyErr_SetString`
* :c:func:`HPyErr_WarnEx`
* :c:func:`HPyErr_WriteUnraisable`
* :c:func:`HPyField_Load`
* :c:func:`HPyField_Store`
* :c:func:`HPyFloat_AsDouble`
* :c:func:`HPyFloat_FromDouble`
* :c:func:`HPyGlobal_Load`
* :c:func:`HPyGlobal_Store`
* :c:func:`HPyImport_ImportModule`
* :c:func:`HPyListBuilder_Build`
* :c:func:`HPyListBuilder_Cancel`
* :c:func:`HPyListBuilder_New`
* :c:func:`HPyListBuilder_Set`
* :c:func:`HPyList_Append`
* :c:func:`HPyList_Check`
* :c:func:`HPyList_New`
* :c:func:`HPyLong_AsDouble`
* :c:func:`HPyLong_AsInt32_t`
* :c:func:`HPyLong_AsInt64_t`
* :c:func:`HPyLong_AsSize_t`
* :c:func:`HPyLong_AsSsize_t`
* :c:func:`HPyLong_AsUInt32_t`
* :c:func:`HPyLong_AsUInt32_tMask`
* :c:func:`HPyLong_AsUInt64_t`
* :c:func:`HPyLong_AsUInt64_tMask`
* :c:func:`HPyLong_AsVoidPtr`
* :c:func:`HPyLong_FromInt32_t`
* :c:func:`HPyLong_FromInt64_t`
* :c:func:`HPyLong_FromSize_t`
* :c:func:`HPyLong_FromSsize_t`
* :c:func:`HPyLong_FromUInt32_t`
* :c:func:`HPyLong_FromUInt64_t`
* :c:func:`HPyNumber_Check`
* :c:func:`HPySlice_Unpack`
* :c:func:`HPyTracker_Add`
* :c:func:`HPyTracker_Close`
* :c:func:`HPyTracker_ForgetAll`
* :c:func:`HPyTracker_New`
* :c:func:`HPyTupleBuilder_Build`
* :c:func:`HPyTupleBuilder_Cancel`
* :c:func:`HPyTupleBuilder_New`
* :c:func:`HPyTupleBuilder_Set`
* :c:func:`HPyTuple_Check`
* :c:func:`HPyTuple_FromArray`
* :c:func:`HPyType_FromSpec`
* :c:func:`HPyType_GenericNew`
* :c:func:`HPyType_GetName`
* :c:func:`HPyType_IsSubtype`
* :c:func:`HPyUnicode_AsASCIIString`
* :c:func:`HPyUnicode_AsLatin1String`
* :c:func:`HPyUnicode_AsUTF8AndSize`
* :c:func:`HPyUnicode_AsUTF8String`
* :c:func:`HPyUnicode_Check`
* :c:func:`HPyUnicode_DecodeASCII`
* :c:func:`HPyUnicode_DecodeFSDefault`
* :c:func:`HPyUnicode_DecodeFSDefaultAndSize`
* :c:func:`HPyUnicode_DecodeLatin1`
* :c:func:`HPyUnicode_EncodeFSDefault`
* :c:func:`HPyUnicode_FromEncodedObject`
* :c:func:`HPyUnicode_FromString`
* :c:func:`HPyUnicode_FromWideChar`
* :c:func:`HPyUnicode_ReadChar`
* :c:func:`HPyUnicode_Substring`
* :c:func:`HPy_ASCII`
* :c:func:`HPy_Absolute`
* :c:func:`HPy_Add`
* :c:func:`HPy_And`
* :c:func:`HPy_AsPyObject`
* :c:func:`HPy_Bytes`
* :c:func:`HPy_Call`
* :c:func:`HPy_CallMethod`
* :c:func:`HPy_CallTupleDict`
* :c:func:`HPy_Close`
* :c:func:`HPy_Compile_s`
* :c:func:`HPy_Contains`
* :c:func:`HPy_DelItem`
* :c:func:`HPy_DelItem_i`
* :c:func:`HPy_DelItem_s`
* :c:func:`HPy_Divmod`
* :c:func:`HPy_Dup`
* :c:func:`HPy_EvalCode`
* :c:func:`HPy_FatalError`
* :c:func:`HPy_Float`
* :c:func:`HPy_FloorDivide`
* :c:func:`HPy_FromPyObject`
* :c:func:`HPy_GetAttr`
* :c:func:`HPy_GetAttr_s`
* :c:func:`HPy_GetItem`
* :c:func:`HPy_GetItem_i`
* :c:func:`HPy_GetItem_s`
* :c:func:`HPy_HasAttr`
* :c:func:`HPy_HasAttr_s`
* :c:func:`HPy_Hash`
* :c:func:`HPy_InPlaceAdd`
* :c:func:`HPy_InPlaceAnd`
* :c:func:`HPy_InPlaceFloorDivide`
* :c:func:`HPy_InPlaceLshift`
* :c:func:`HPy_InPlaceMatrixMultiply`
* :c:func:`HPy_InPlaceMultiply`
* :c:func:`HPy_InPlaceOr`
* :c:func:`HPy_InPlacePower`
* :c:func:`HPy_InPlaceRemainder`
* :c:func:`HPy_InPlaceRshift`
* :c:func:`HPy_InPlaceSubtract`
* :c:func:`HPy_InPlaceTrueDivide`
* :c:func:`HPy_InPlaceXor`
* :c:func:`HPy_Index`
* :c:func:`HPy_Invert`
* :c:func:`HPy_Is`
* :c:func:`HPy_IsTrue`
* :c:func:`HPy_LeavePythonExecution`
* :c:func:`HPy_Length`
* :c:func:`HPy_Long`
* :c:func:`HPy_Lshift`
* :c:func:`HPy_MatrixMultiply`
* :c:func:`HPy_Multiply`
* :c:func:`HPy_Negative`
* :c:func:`HPy_Or`
* :c:func:`HPy_Positive`
* :c:func:`HPy_Power`
* :c:func:`HPy_ReenterPythonExecution`
* :c:func:`HPy_Remainder`
* :c:func:`HPy_Repr`
* :c:func:`HPy_RichCompare`
* :c:func:`HPy_RichCompareBool`
* :c:func:`HPy_Rshift`
* :c:func:`HPy_SetAttr`
* :c:func:`HPy_SetAttr_s`
* :c:func:`HPy_SetCallFunction`
* :c:func:`HPy_SetItem`
* :c:func:`HPy_SetItem_i`
* :c:func:`HPy_SetItem_s`
* :c:func:`HPy_Str`
* :c:func:`HPy_Subtract`
* :c:func:`HPy_TrueDivide`
* :c:func:`HPy_Type`
* :c:func:`HPy_TypeCheck`
* :c:func:`HPy_Xor`
